==> org-lsst-sal-cccamera-2.1.1-sources.jar: org/lsst/sal/cccamera/event/FocalPlaneHardwareIdSettingsAppliedEvent.java <==
package org.lsst.sal.cccamera.event;

import org.lsst.sal.camera.CameraEvent;

public class FocalPlaneHardwareIdSettingsAppliedEvent extends CameraEvent {
  private final int version;

  private final String rebLocation;

  private final String rebSerialNumber;

  private final String rebLSSTName;

  private final String ccdLocation;

  private final String ccdLSSTNum;

  private final String ccdManSerNum;

  public FocalPlaneHardwareIdSettingsAppliedEvent(int priority, int version, String rebLocation,
      String rebSerialNumber, String rebLSSTName, String ccdLocation, String ccdLSSTNum,
      String ccdManSerNum) {
    super (priority);
    this.version = version;
    this.rebLocation = rebLocation;
    this.rebSerialNumber = rebSerialNumber;
    this.rebLSSTName = rebLSSTName;
    this.ccdLocation = ccdLocation;
    this.ccdLSSTNum = ccdLSSTNum;
    this.ccdManSerNum = ccdManSerNum;
  }

  public int getVersion() {
    return version;
  }

  public String getRebLocation() {
    return rebLocation;
  }

  public String getRebSerialNumber() {
    return rebSerialNumber;
  }

  public String getRebLSSTName() {
    return rebLSSTName;
  }

  public String getCcdLocation() {
    return ccdLocation;
  }

  public String getCcdLSSTNum() {
    return ccdLSSTNum;
  }

  public String getCcdManSerNum() {
    return ccdManSerNum;
  }

  @Override
  public String toString() {
    return "FocalPlaneHardwareIdSettingsAppliedEvent{" + "version=" + version +
        ", rebLocation=" + rebLocation +", rebSerialNumber=" + rebSerialNumber +
        ", rebLSSTName=" + rebLSSTName +", ccdLocation=" + ccdLocation +
        ", ccdLSSTNum=" + ccdLSSTNum +", ccdManSerNum=" + ccdManSerNum +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private int priority;

    private int version;

    private String rebLocation;

    private String rebSerialNumber;

    private String rebLSSTName;

    private String ccdLocation;

    private String ccdLSSTNum;

    private String ccdManSerNum;

    private Builder() {
    }

    public Builder priority(int priority) {
      this.priority = priority;
      return this;
    }

    public Builder version(int version) {
      this.version = version;
      return this;
    }

    public Builder rebLocation(String rebLocation) {
      this.rebLocation = rebLocation;
      return this;
    }

    public Builder rebSerialNumber(String rebSerialNumber) {
      this.rebSerialNumber = rebSerialNumber;
      return this;
    }

    public Builder rebLSSTName(String rebLSSTName) {
      this.rebLSSTName = rebLSSTName;
      return this;
    }

    public Builder ccdLocation(String ccdLocation) {
      this.ccdLocation = ccdLocation;
      return this;
    }

    public Builder ccdLSSTNum(String ccdLSSTNum) {
      this.ccdLSSTNum = ccdLSSTNum;
      return this;
    }

    public Builder ccdManSerNum(String ccdManSerNum) {
      this.ccdManSerNum = ccdManSerNum;
      return this;
    }

    public FocalPlaneHardwareIdSettingsAppliedEvent build() {
      return new FocalPlaneHardwareIdSettingsAppliedEvent(priority, version, rebLocation, rebSerialNumber, rebLSSTName, ccdLocation, ccdLSSTNum, ccdManSerNum);
    }
  }
}

==> org-lsst-sal-cccamera-2.2.11-sources.jar: org/lsst/sal/cccamera/event/FocalPlaneHardwareIdSettingsAppliedEvent.java <==
package org.lsst.sal.cccamera.event;

import org.lsst.sal.camera.CameraEvent;

public class FocalPlaneHardwareIdSettingsAppliedEvent extends CameraEvent {
  private final int version;

  private final String rebLocation;

  private final String rebLSSTName;

  private final String ccdLocation;

  private final String ccdLSSTName;

  private final String ccdManSerNum;

  private final String raftLocation;

  private final String raftLSSTName;

  public FocalPlaneHardwareIdSettingsAppliedEvent(int priority, int version, String rebLocation,
      String rebLSSTName, String ccdLocation, String ccdLSSTName, String ccdManSerNum,
      String raftLocation, String raftLSSTName) {
    super (priority);
    this.version = version;
    this.rebLocation = rebLocation;
    this.rebLSSTName = rebLSSTName;
    this.ccdLocation = ccdLocation;
    this.ccdLSSTName = ccdLSSTName;
    this.ccdManSerNum = ccdManSerNum;
    this.raftLocation = raftLocation;
    this.raftLSSTName = raftLSSTName;
  }

  public int getVersion() {
    return version;
  }

  public String getRebLocation() {
    return rebLocation;
  }

  public String getRebLSSTName() {
    return rebLSSTName;
  }

  public String getCcdLocation() {
    return ccdLocation;
  }

  public String getCcdLSSTName() {
    return ccdLSSTName;
  }

  public String getCcdManSerNum() {
    return ccdManSerNum;
  }

  public String getRaftLocation() {
    return raftLocation;
  }

  public String getRaftLSSTName() {
    return raftLSSTName;
  }

  @Override
  public String toString() {
    return "FocalPlaneHardwareIdSettingsAppliedEvent{" + "version=" + version +
        ", rebLocation=" + rebLocation +", rebLSSTName=" + rebLSSTName +
        ", ccdLocation=" + ccdLocation +", ccdLSSTName=" + ccdLSSTName +
        ", ccdManSerNum=" + ccdManSerNum +", raftLocation=" + raftLocation +
        ", raftLSSTName=" + raftLSSTName +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private int priority;

    private int version;

    private String rebLocation;

    private String rebLSSTName;

    private String ccdLocation;

    private String ccdLSSTName;

    private String ccdManSerNum;

    private String raftLocation;

    private String raftLSSTName;

    private Builder() {
    }

    public Builder priority(int priority) {
      this.priority = priority;
      return this;
    }

    public Builder version(int version) {
      this.version = version;
      return this;
    }

    public Builder rebLocation(String rebLocation) {
      this.rebLocation = rebLocation;
      return this;
    }

    public Builder rebLSSTName(String rebLSSTName) {
      this.rebLSSTName = rebLSSTName;
      return this;
    }

    public Builder ccdLocation(String ccdLocation) {
      this.ccdLocation = ccdLocation;
      return this;
    }

    public Builder ccdLSSTName(String ccdLSSTName) {
      this.ccdLSSTName = ccdLSSTName;
      return this;
    }

    public Builder ccdManSerNum(String ccdManSerNum) {
      this.ccdManSerNum = ccdManSerNum;
      return this;
    }

    public Builder raftLocation(String raftLocation) {
      this.raftLocation = raftLocation;
      return this;
    }

    public Builder raftLSSTName(String raftLSSTName) {
      this.raftLSSTName = raftLSSTName;
      return this;
    }

    public FocalPlaneHardwareIdSettingsAppliedEvent build() {
      return new FocalPlaneHardwareIdSettingsAppliedEvent(priority, version, rebLocation, rebLSSTName, ccdLocation, ccdLSSTName, ccdManSerNum, raftLocation, raftLSSTName);
    }
  }
}
